==> igniteui-react-charts-18.7.2.tgz: package/esm5/lib/DataPieChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var DataPieChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataPieChartToolbarProvider, _super);
    function DataPieChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ad = null;
        return _this;
    }
    DataPieChartToolbarProvider.prototype.g = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.afu != null;
                }
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.z = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "AngleAxisMajorStroke":
                this.h("ShowGridlines", 2, a.afu != null);
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.p = function (a, b) {
        var c = a;
        if (this.c(b, "ShowGridlines")) {
            if (c.afu == null) {
                if (this.ad != null) {
                    c.afu = this.ad;
                }
                else {
                    c.afu = c.dataChart.z6;
                }
            }
        }
        else {
            if (c.afu != null) {
                this.ad = c.afu;
                c.afu = null;
            }
        }
    };
    DataPieChartToolbarProvider.$t = markType(DataPieChartToolbarProvider, 'DataPieChartToolbarProvider', DomainChartToolbarProvider.$);
    return DataPieChartToolbarProvider;
}(DomainChartToolbarProvider));
export { DataPieChartToolbarProvider };

==> igniteui-react-charts-19.0.0.tgz: package/esm5/lib/DataPieChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var DataPieChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataPieChartToolbarProvider, _super);
    function DataPieChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ah = null;
        return _this;
    }
    DataPieChartToolbarProvider.prototype.j = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.agy != null;
                }
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.ac = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "AngleAxisMajorStroke":
                this.k("ShowGridlines", 2, a.agy != null);
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.s = function (a, b) {
        var c = a;
        if (this.h(b, "ShowGridlines")) {
            if (c.agy == null) {
                if (this.ah != null) {
                    c.agy = this.ah;
                }
                else {
                    c.agy = c.dataChart.aa5;
                }
            }
        }
        else {
            if (c.agy != null) {
                this.ah = c.agy;
                c.agy = null;
            }
        }
    };
    DataPieChartToolbarProvider.$t = markType(DataPieChartToolbarProvider, 'DataPieChartToolbarProvider', DomainChartToolbarProvider.$);
    return DataPieChartToolbarProvider;
}(DomainChartToolbarProvider));
export { DataPieChartToolbarProvider };
